# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_project.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gcp/gcp_project.proto\x12\x17oak9.tython.gcp.project\x1a\x13shared/shared.proto\"P\n\x10ProjectXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0c\n\x04read\x18\x03 \x01(\t\x12\x0e\n\x06update\x18\x04 \x01(\t\"\x98\x03\n\x07Project\x12\x1b\n\x13\x61uto_create_network\x18\x01 \x01(\x08\x12\x17\n\x0f\x62illing_account\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12<\n\x06labels\x18\x05 \x03(\x0b\x32,.oak9.tython.gcp.project.Project.LabelsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0e\n\x06number\x18\x07 \x01(\t\x12\x0e\n\x06org_id\x18\x08 \x01(\t\x12\x12\n\nproject_id\x18\t \x01(\t\x12\x13\n\x0bskip_delete\x18\n \x01(\x08\x12;\n\x08timeouts\x18\x0b \x01(\x0b\x32).oak9.tython.gcp.project.ProjectXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n.ProjectAccessApprovalSettingsXEnrolledServices\x12\x15\n\rcloud_product\x18\x01 \x01(\t\x12\x18\n\x10\x65nrollment_level\x18\x02 \x01(\t\"X\n&ProjectAccessApprovalSettingsXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe8\x03\n\x1dProjectAccessApprovalSettings\x12\x1a\n\x12\x61\x63tive_key_version\x18\x01 \x01(\t\x12\'\n\x1f\x61ncestor_has_active_key_version\x18\x02 \x01(\x08\x12\x19\n\x11\x65nrolled_ancestor\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x1b\n\x13invalid_key_version\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x1b\n\x13notification_emails\x18\x07 \x03(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x12\n\nproject_id\x18\t \x01(\t\x12\x62\n\x11\x65nrolled_services\x18\n \x03(\x0b\x32G.oak9.tython.gcp.project.ProjectAccessApprovalSettingsXEnrolledServices\x12Q\n\x08timeouts\x18\x0b \x01(\x0b\x32?.oak9.tython.gcp.project.ProjectAccessApprovalSettingsXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"V\n&ProjectDefaultServiceAccountsXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0c\n\x04read\x18\x03 \x01(\t\"\x8f\x03\n\x1dProjectDefaultServiceAccounts\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x16\n\x0erestore_policy\x18\x04 \x01(\t\x12\x65\n\x10service_accounts\x18\x05 \x03(\x0b\x32K.oak9.tython.gcp.project.ProjectDefaultServiceAccounts.ServiceAccountsEntry\x12Q\n\x08timeouts\x18\x06 \x01(\x0b\x32?.oak9.tython.gcp.project.ProjectDefaultServiceAccountsXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x36\n\x14ServiceAccountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"R\n$ProjectIamAuditConfigXAuditLogConfig\x12\x18\n\x10\x65xempted_members\x18\x01 \x03(\t\x12\x10\n\x08log_type\x18\x02 \x01(\t\"\xe5\x01\n\x15ProjectIamAuditConfig\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\x12W\n\x10\x61udit_log_config\x18\x05 \x03(\x0b\x32=.oak9.tython.gcp.project.ProjectIamAuditConfigXAuditLogConfig\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"U\n\x1bProjectIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xdf\x01\n\x11ProjectIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12G\n\tcondition\x18\x06 \x01(\x0b\x32\x34.oak9.tython.gcp.project.ProjectIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe4\x01\n\x14ProjectIamCustomRole\x12\x0f\n\x07\x64\x65leted\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0bpermissions\x18\x05 \x03(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0f\n\x07role_id\x18\x07 \x01(\t\x12\r\n\x05stage\x18\x08 \x01(\t\x12\r\n\x05title\x18\t \x01(\t\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"T\n\x1aProjectIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xdc\x01\n\x10ProjectIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x46\n\tcondition\x18\x06 \x01(\x0b\x32\x33.oak9.tython.gcp.project.ProjectIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8b\x01\n\x10ProjectIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\";\n\'ProjectOrganizationPolicyXBooleanPolicy\x12\x10\n\x08\x65nforced\x18\x01 \x01(\x08\"I\n*ProjectOrganizationPolicyXListPolicyXAllow\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\x12\x0e\n\x06values\x18\x02 \x03(\t\"H\n)ProjectOrganizationPolicyXListPolicyXDeny\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\x12\x0e\n\x06values\x18\x02 \x03(\t\"\x82\x02\n$ProjectOrganizationPolicyXListPolicy\x12\x1b\n\x13inherit_from_parent\x18\x01 \x01(\x08\x12\x17\n\x0fsuggested_value\x18\x02 \x01(\t\x12R\n\x05\x61llow\x18\x03 \x01(\x0b\x32\x43.oak9.tython.gcp.project.ProjectOrganizationPolicyXListPolicyXAllow\x12P\n\x04\x64\x65ny\x18\x04 \x01(\x0b\x32\x42.oak9.tython.gcp.project.ProjectOrganizationPolicyXListPolicyXDeny\":\n\'ProjectOrganizationPolicyXRestorePolicy\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\x08\"b\n\"ProjectOrganizationPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0c\n\x04read\x18\x03 \x01(\t\x12\x0e\n\x06update\x18\x04 \x01(\t\"\x90\x04\n\x19ProjectOrganizationPolicy\x12\x12\n\nconstraint\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x13\n\x0bupdate_time\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\x01\x12X\n\x0e\x62oolean_policy\x18\x07 \x01(\x0b\x32@.oak9.tython.gcp.project.ProjectOrganizationPolicyXBooleanPolicy\x12R\n\x0blist_policy\x18\x08 \x01(\x0b\x32=.oak9.tython.gcp.project.ProjectOrganizationPolicyXListPolicy\x12X\n\x0erestore_policy\x18\t \x01(\x0b\x32@.oak9.tython.gcp.project.ProjectOrganizationPolicyXRestorePolicy\x12M\n\x08timeouts\x18\n \x01(\x0b\x32;.oak9.tython.gcp.project.ProjectOrganizationPolicyXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n\x17ProjectServiceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0c\n\x04read\x18\x03 \x01(\t\x12\x0e\n\x06update\x18\x04 \x01(\t\"\xfb\x01\n\x0eProjectService\x12\"\n\x1a\x64isable_dependent_services\x18\x01 \x01(\x08\x12\x1a\n\x12\x64isable_on_destroy\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0f\n\x07service\x18\x05 \x01(\t\x12\x42\n\x08timeouts\x18\x06 \x01(\x0b\x32\x30.oak9.tython.gcp.project.ProjectServiceXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"C\n!ProjectUsageExportBucketXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xe3\x01\n\x18ProjectUsageExportBucket\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06prefix\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12L\n\x08timeouts\x18\x05 \x01(\x0b\x32:.oak9.tython.gcp.project.ProjectUsageExportBucketXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_project_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROJECT_LABELSENTRY._options = None
  _PROJECT_LABELSENTRY._serialized_options = b'8\001'
  _PROJECTDEFAULTSERVICEACCOUNTS_SERVICEACCOUNTSENTRY._options = None
  _PROJECTDEFAULTSERVICEACCOUNTS_SERVICEACCOUNTSENTRY._serialized_options = b'8\001'
  _PROJECTXTIMEOUTS._serialized_start=71
  _PROJECTXTIMEOUTS._serialized_end=151
  _PROJECT._serialized_start=154
  _PROJECT._serialized_end=562
  _PROJECT_LABELSENTRY._serialized_start=517
  _PROJECT_LABELSENTRY._serialized_end=562
  _PROJECTACCESSAPPROVALSETTINGSXENROLLEDSERVICES._serialized_start=564
  _PROJECTACCESSAPPROVALSETTINGSXENROLLEDSERVICES._serialized_end=661
  _PROJECTACCESSAPPROVALSETTINGSXTIMEOUTS._serialized_start=663
  _PROJECTACCESSAPPROVALSETTINGSXTIMEOUTS._serialized_end=751
  _PROJECTACCESSAPPROVALSETTINGS._serialized_start=754
  _PROJECTACCESSAPPROVALSETTINGS._serialized_end=1242
  _PROJECTDEFAULTSERVICEACCOUNTSXTIMEOUTS._serialized_start=1244
  _PROJECTDEFAULTSERVICEACCOUNTSXTIMEOUTS._serialized_end=1330
  _PROJECTDEFAULTSERVICEACCOUNTS._serialized_start=1333
  _PROJECTDEFAULTSERVICEACCOUNTS._serialized_end=1732
  _PROJECTDEFAULTSERVICEACCOUNTS_SERVICEACCOUNTSENTRY._serialized_start=1678
  _PROJECTDEFAULTSERVICEACCOUNTS_SERVICEACCOUNTSENTRY._serialized_end=1732
  _PROJECTIAMAUDITCONFIGXAUDITLOGCONFIG._serialized_start=1734
  _PROJECTIAMAUDITCONFIGXAUDITLOGCONFIG._serialized_end=1816
  _PROJECTIAMAUDITCONFIG._serialized_start=1819
  _PROJECTIAMAUDITCONFIG._serialized_end=2048
  _PROJECTIAMBINDINGXCONDITION._serialized_start=2050
  _PROJECTIAMBINDINGXCONDITION._serialized_end=2135
  _PROJECTIAMBINDING._serialized_start=2138
  _PROJECTIAMBINDING._serialized_end=2361
  _PROJECTIAMCUSTOMROLE._serialized_start=2364
  _PROJECTIAMCUSTOMROLE._serialized_end=2592
  _PROJECTIAMMEMBERXCONDITION._serialized_start=2594
  _PROJECTIAMMEMBERXCONDITION._serialized_end=2678
  _PROJECTIAMMEMBER._serialized_start=2681
  _PROJECTIAMMEMBER._serialized_end=2901
  _PROJECTIAMPOLICY._serialized_start=2904
  _PROJECTIAMPOLICY._serialized_end=3043
  _PROJECTORGANIZATIONPOLICYXBOOLEANPOLICY._serialized_start=3045
  _PROJECTORGANIZATIONPOLICYXBOOLEANPOLICY._serialized_end=3104
  _PROJECTORGANIZATIONPOLICYXLISTPOLICYXALLOW._serialized_start=3106
  _PROJECTORGANIZATIONPOLICYXLISTPOLICYXALLOW._serialized_end=3179
  _PROJECTORGANIZATIONPOLICYXLISTPOLICYXDENY._serialized_start=3181
  _PROJECTORGANIZATIONPOLICYXLISTPOLICYXDENY._serialized_end=3253
  _PROJECTORGANIZATIONPOLICYXLISTPOLICY._serialized_start=3256
  _PROJECTORGANIZATIONPOLICYXLISTPOLICY._serialized_end=3514
  _PROJECTORGANIZATIONPOLICYXRESTOREPOLICY._serialized_start=3516
  _PROJECTORGANIZATIONPOLICYXRESTOREPOLICY._serialized_end=3574
  _PROJECTORGANIZATIONPOLICYXTIMEOUTS._serialized_start=3576
  _PROJECTORGANIZATIONPOLICYXTIMEOUTS._serialized_end=3674
  _PROJECTORGANIZATIONPOLICY._serialized_start=3677
  _PROJECTORGANIZATIONPOLICY._serialized_end=4205
  _PROJECTSERVICEXTIMEOUTS._serialized_start=4207
  _PROJECTSERVICEXTIMEOUTS._serialized_end=4294
  _PROJECTSERVICE._serialized_start=4297
  _PROJECTSERVICE._serialized_end=4548
  _PROJECTUSAGEEXPORTBUCKETXTIMEOUTS._serialized_start=4550
  _PROJECTUSAGEEXPORTBUCKETXTIMEOUTS._serialized_end=4617
  _PROJECTUSAGEEXPORTBUCKET._serialized_start=4620
  _PROJECTUSAGEEXPORTBUCKET._serialized_end=4847
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_privateEndpoints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_ENDPOINTS_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINTS_PRIVATE_DNS_ZONE_GROUPS_FIELD_NUMBER: builtins.int
    @property
    def private_endpoints(self) -> global___PrivateEndpoints: ...
    @property
    def private_endpoints_private_dns_zone_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateEndpointsPrivateDnsZoneGroups]: ...
    def __init__(
        self,
        *,
        private_endpoints: global___PrivateEndpoints | None = ...,
        private_endpoints_private_dns_zone_groups: collections.abc.Iterable[global___PrivateEndpointsPrivateDnsZoneGroups] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoints", b"private_endpoints"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["private_endpoints", b"private_endpoints", "private_endpoints_private_dns_zone_groups", b"private_endpoints_private_dns_zone_groups"]) -> None: ...

global___Microsoft_Network_privateEndpoints = Microsoft_Network_privateEndpoints

@typing_extensions.final
class Subnet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___Subnet = Subnet

@typing_extensions.final
class PrivateEndpointsPrivateDnsZoneGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONE_CONFIGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_dns_zone_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsZoneConfig]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_dns_zone_configs: collections.abc.Iterable[global___PrivateDnsZoneConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_dns_zone_configs", b"private_dns_zone_configs", "resource_info", b"resource_info"]) -> None: ...

global___PrivateEndpointsPrivateDnsZoneGroups = PrivateEndpointsPrivateDnsZoneGroups

@typing_extensions.final
class PrivateDnsZoneConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    private_dns_zone_id: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        private_dns_zone_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_dns_zone_id", b"private_dns_zone_id"]) -> None: ...

global___PrivateDnsZoneConfig = PrivateDnsZoneConfig

@typing_extensions.final
class PrivateEndpoints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    EXTENDED_LOCATION_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTIONS_FIELD_NUMBER: builtins.int
    MANUAL_PRIVATE_LINK_SERVICE_CONNECTIONS_FIELD_NUMBER: builtins.int
    CUSTOM_DNS_CONFIGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    location: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def extended_location(self) -> global___ExtendedLocation: ...
    @property
    def subnet(self) -> global___Subnet: ...
    @property
    def private_link_service_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateLinkServiceConnection]: ...
    @property
    def manual_private_link_service_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateLinkServiceConnection]: ...
    @property
    def custom_dns_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomDnsConfigPropertiesFormat]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        extended_location: global___ExtendedLocation | None = ...,
        subnet: global___Subnet | None = ...,
        private_link_service_connections: collections.abc.Iterable[global___PrivateLinkServiceConnection] | None = ...,
        manual_private_link_service_connections: collections.abc.Iterable[global___PrivateLinkServiceConnection] | None = ...,
        custom_dns_configs: collections.abc.Iterable[global___CustomDnsConfigPropertiesFormat] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extended_location", b"extended_location", "resource_info", b"resource_info", "subnet", b"subnet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_dns_configs", b"custom_dns_configs", "extended_location", b"extended_location", "location", b"location", "manual_private_link_service_connections", b"manual_private_link_service_connections", "name", b"name", "private_link_service_connections", b"private_link_service_connections", "resource_info", b"resource_info", "subnet", b"subnet", "tags", b"tags"]) -> None: ...

global___PrivateEndpoints = PrivateEndpoints

@typing_extensions.final
class CustomDnsConfigPropertiesFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FQDN_FIELD_NUMBER: builtins.int
    IP_ADDRESSES_FIELD_NUMBER: builtins.int
    fqdn: builtins.str
    @property
    def ip_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        fqdn: builtins.str = ...,
        ip_addresses: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fqdn", b"fqdn", "ip_addresses", b"ip_addresses"]) -> None: ...

global___CustomDnsConfigPropertiesFormat = CustomDnsConfigPropertiesFormat

@typing_extensions.final
class PrivateLinkServiceConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_LINK_SERVICE_ID_FIELD_NUMBER: builtins.int
    GROUP_IDS_FIELD_NUMBER: builtins.int
    REQUEST_MESSAGE_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    private_link_service_id: builtins.str
    @property
    def group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    request_message: builtins.str
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    name: builtins.str
    def __init__(
        self,
        *,
        private_link_service_id: builtins.str = ...,
        group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        request_message: builtins.str = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_link_service_connection_state", b"private_link_service_connection_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_ids", b"group_ids", "name", b"name", "private_link_service_connection_state", b"private_link_service_connection_state", "private_link_service_id", b"private_link_service_id", "request_message", b"request_message"]) -> None: ...

global___PrivateLinkServiceConnection = PrivateLinkServiceConnection

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    status: builtins.str
    description: builtins.str
    actions_required: builtins.str
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        description: builtins.str = ...,
        actions_required: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class ExtendedLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___ExtendedLocation = ExtendedLocation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeEnvironmentLaunchTemplateSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    launch_template_name: builtins.str
    version: builtins.str
    launch_template_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        launch_template_name: builtins.str = ...,
        version: builtins.str = ...,
        launch_template_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["launch_template_id", b"launch_template_id", "launch_template_name", b"launch_template_name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___ComputeEnvironmentLaunchTemplateSpecification = ComputeEnvironmentLaunchTemplateSpecification

@typing_extensions.final
class ComputeEnvironmentComputeResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SPOT_IAM_FLEET_ROLE_FIELD_NUMBER: builtins.int
    MAXV_CPUS_FIELD_NUMBER: builtins.int
    BID_PERCENTAGE_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SUBNETS_FIELD_NUMBER: builtins.int
    ALLOCATION_STRATEGY_FIELD_NUMBER: builtins.int
    MINV_CPUS_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_FIELD_NUMBER: builtins.int
    IMAGE_ID_FIELD_NUMBER: builtins.int
    INSTANCE_ROLE_FIELD_NUMBER: builtins.int
    INSTANCE_TYPES_FIELD_NUMBER: builtins.int
    EC2_KEY_PAIR_FIELD_NUMBER: builtins.int
    PLACEMENT_GROUP_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DESIREDV_CPUS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    spot_iam_fleet_role: builtins.str
    maxv_cpus: builtins.int
    bid_percentage: builtins.int
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    allocation_strategy: builtins.str
    minv_cpus: builtins.int
    @property
    def launch_template(self) -> global___ComputeEnvironmentLaunchTemplateSpecification: ...
    image_id: builtins.str
    instance_role: builtins.str
    @property
    def instance_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    ec2_key_pair: builtins.str
    placement_group: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    desiredv_cpus: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        spot_iam_fleet_role: builtins.str = ...,
        maxv_cpus: builtins.int = ...,
        bid_percentage: builtins.int = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        subnets: collections.abc.Iterable[builtins.str] | None = ...,
        allocation_strategy: builtins.str = ...,
        minv_cpus: builtins.int = ...,
        launch_template: global___ComputeEnvironmentLaunchTemplateSpecification | None = ...,
        image_id: builtins.str = ...,
        instance_role: builtins.str = ...,
        instance_types: collections.abc.Iterable[builtins.str] | None = ...,
        ec2_key_pair: builtins.str = ...,
        placement_group: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        desiredv_cpus: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["launch_template", b"launch_template", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allocation_strategy", b"allocation_strategy", "bid_percentage", b"bid_percentage", "desiredv_cpus", b"desiredv_cpus", "ec2_key_pair", b"ec2_key_pair", "image_id", b"image_id", "instance_role", b"instance_role", "instance_types", b"instance_types", "launch_template", b"launch_template", "maxv_cpus", b"maxv_cpus", "minv_cpus", b"minv_cpus", "placement_group", b"placement_group", "resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "spot_iam_fleet_role", b"spot_iam_fleet_role", "subnets", b"subnets", "tags", b"tags"]) -> None: ...

global___ComputeEnvironmentComputeResources = ComputeEnvironmentComputeResources

@typing_extensions.final
class ComputeEnvironment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_FIELD_NUMBER: builtins.int
    COMPUTE_ENVIRONMENT_NAME_FIELD_NUMBER: builtins.int
    COMPUTE_RESOURCES_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    type: builtins.str
    service_role: builtins.str
    compute_environment_name: builtins.str
    @property
    def compute_resources(self) -> global___ComputeEnvironmentComputeResources: ...
    state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        type: builtins.str = ...,
        service_role: builtins.str = ...,
        compute_environment_name: builtins.str = ...,
        compute_resources: global___ComputeEnvironmentComputeResources | None = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compute_resources", b"compute_resources", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_environment_name", b"compute_environment_name", "compute_resources", b"compute_resources", "resource_info", b"resource_info", "service_role", b"service_role", "state", b"state", "type", b"type"]) -> None: ...

global___ComputeEnvironment = ComputeEnvironment

@typing_extensions.final
class Batch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_ENVIRONMENT_FIELD_NUMBER: builtins.int
    JOB_DEFINITION_FIELD_NUMBER: builtins.int
    JOB_QUEUE_FIELD_NUMBER: builtins.int
    @property
    def compute_environment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeEnvironment]: ...
    @property
    def job_definition(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobDefinition]: ...
    @property
    def job_queue(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobQueue]: ...
    def __init__(
        self,
        *,
        compute_environment: collections.abc.Iterable[global___ComputeEnvironment] | None = ...,
        job_definition: collections.abc.Iterable[global___JobDefinition] | None = ...,
        job_queue: collections.abc.Iterable[global___JobQueue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_environment", b"compute_environment", "job_definition", b"job_definition", "job_queue", b"job_queue"]) -> None: ...

global___Batch = Batch

@typing_extensions.final
class JobDefinitionSecret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FROM_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value_from: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value_from: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value_from", b"value_from"]) -> None: ...

global___JobDefinitionSecret = JobDefinitionSecret

@typing_extensions.final
class JobDefinitionTmpfs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    CONTAINER_PATH_FIELD_NUMBER: builtins.int
    MOUNT_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    size: builtins.int
    container_path: builtins.str
    @property
    def mount_options(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        size: builtins.int = ...,
        container_path: builtins.str = ...,
        mount_options: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_path", b"container_path", "mount_options", b"mount_options", "resource_info", b"resource_info", "size", b"size"]) -> None: ...

global___JobDefinitionTmpfs = JobDefinitionTmpfs

@typing_extensions.final
class JobDefinitionDevice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HOST_PATH_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    CONTAINER_PATH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    host_path: builtins.str
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    container_path: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        host_path: builtins.str = ...,
        permissions: collections.abc.Iterable[builtins.str] | None = ...,
        container_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_path", b"container_path", "host_path", b"host_path", "permissions", b"permissions", "resource_info", b"resource_info"]) -> None: ...

global___JobDefinitionDevice = JobDefinitionDevice

@typing_extensions.final
class JobDefinitionLinuxParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SWAPPINESS_FIELD_NUMBER: builtins.int
    TMPFS_FIELD_NUMBER: builtins.int
    SHARED_MEMORY_SIZE_FIELD_NUMBER: builtins.int
    DEVICES_FIELD_NUMBER: builtins.int
    INIT_PROCESS_ENABLED_FIELD_NUMBER: builtins.int
    MAX_SWAP_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    swappiness: builtins.int
    @property
    def tmpfs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobDefinitionTmpfs]: ...
    shared_memory_size: builtins.int
    @property
    def devices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobDefinitionDevice]: ...
    init_process_enabled: builtins.bool
    max_swap: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        swappiness: builtins.int = ...,
        tmpfs: collections.abc.Iterable[global___JobDefinitionTmpfs] | None = ...,
        shared_memory_size: builtins.int = ...,
        devices: collections.abc.Iterable[global___JobDefinitionDevice] | None = ...,
        init_process_enabled: builtins.bool = ...,
        max_swap: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["devices", b"devices", "init_process_enabled", b"init_process_enabled", "max_swap", b"max_swap", "resource_info", b"resource_info", "shared_memory_size", b"shared_memory_size", "swappiness", b"swappiness", "tmpfs", b"tmpfs"]) -> None: ...

global___JobDefinitionLinuxParameters = JobDefinitionLinuxParameters

@typing_extensions.final
class JobDefinitionResourceRequirement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___JobDefinitionResourceRequirement = JobDefinitionResourceRequirement

@typing_extensions.final
class JobDefinitionLogConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class OptionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECRET_OPTIONS_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    LOG_DRIVER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def secret_options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobDefinitionSecret]: ...
    @property
    def options(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    log_driver: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        secret_options: collections.abc.Iterable[global___JobDefinitionSecret] | None = ...,
        options: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        log_driver: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["log_driver", b"log_driver", "options", b"options", "resource_info", b"resource_info", "secret_options", b"secret_options"]) -> None: ...

global___JobDefinitionLogConfiguration = JobDefinitionLogConfiguration

@typing_extensions.final
class JobDefinitionMountPoints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    SOURCE_VOLUME_FIELD_NUMBER: builtins.int
    CONTAINER_PATH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    read_only: builtins.bool
    source_volume: builtins.str
    container_path: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        read_only: builtins.bool = ...,
        source_volume: builtins.str = ...,
        container_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_path", b"container_path", "read_only", b"read_only", "resource_info", b"resource_info", "source_volume", b"source_volume"]) -> None: ...

global___JobDefinitionMountPoints = JobDefinitionMountPoints

@typing_extensions.final
class JobDefinitionVolumesHost(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SOURCE_PATH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    source_path: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        source_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "source_path", b"source_path"]) -> None: ...

global___JobDefinitionVolumesHost = JobDefinitionVolumesHost

@typing_extensions.final
class JobDefinitionVolumes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def host(self) -> global___JobDefinitionVolumesHost: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        host: global___JobDefinitionVolumesHost | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["host", b"host", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___JobDefinitionVolumes = JobDefinitionVolumes

@typing_extensions.final
class JobDefinitionEnvironment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___JobDefinitionEnvironment = JobDefinitionEnvironment

@typing_extensions.final
class JobDefinitionUlimit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SOFT_LIMIT_FIELD_NUMBER: builtins.int
    HARD_LIMIT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    soft_limit: builtins.int
    hard_limit: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        soft_limit: builtins.int = ...,
        hard_limit: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hard_limit", b"hard_limit", "name", b"name", "resource_info", b"resource_info", "soft_limit", b"soft_limit"]) -> None: ...

global___JobDefinitionUlimit = JobDefinitionUlimit

@typing_extensions.final
class JobDefinitionContainerProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SECRETS_FIELD_NUMBER: builtins.int
    MEMORY_FIELD_NUMBER: builtins.int
    PRIVILEGED_FIELD_NUMBER: builtins.int
    LINUX_PARAMETERS_FIELD_NUMBER: builtins.int
    JOB_ROLE_ARN_FIELD_NUMBER: builtins.int
    READONLY_ROOT_FILESYSTEM_FIELD_NUMBER: builtins.int
    VCPUS_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    RESOURCE_REQUIREMENTS_FIELD_NUMBER: builtins.int
    LOG_CONFIGURATION_FIELD_NUMBER: builtins.int
    MOUNT_POINTS_FIELD_NUMBER: builtins.int
    EXECUTION_ROLE_ARN_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    ULIMITS_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    user: builtins.str
    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobDefinitionSecret]: ...
    memory: builtins.int
    privileged: builtins.bool
    @property
    def linux_parameters(self) -> global___JobDefinitionLinuxParameters: ...
    job_role_arn: builtins.str
    readonly_root_filesystem: builtins.bool
    vcpus: builtins.int
    image: builtins.str
    @property
    def resource_requirements(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobDefinitionResourceRequirement]: ...
    @property
    def log_configuration(self) -> global___JobDefinitionLogConfiguration: ...
    @property
    def mount_points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobDefinitionMountPoints]: ...
    execution_role_arn: builtins.str
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobDefinitionVolumes]: ...
    @property
    def command(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def environment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobDefinitionEnvironment]: ...
    @property
    def ulimits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobDefinitionUlimit]: ...
    instance_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        user: builtins.str = ...,
        secrets: collections.abc.Iterable[global___JobDefinitionSecret] | None = ...,
        memory: builtins.int = ...,
        privileged: builtins.bool = ...,
        linux_parameters: global___JobDefinitionLinuxParameters | None = ...,
        job_role_arn: builtins.str = ...,
        readonly_root_filesystem: builtins.bool = ...,
        vcpus: builtins.int = ...,
        image: builtins.str = ...,
        resource_requirements: collections.abc.Iterable[global___JobDefinitionResourceRequirement] | None = ...,
        log_configuration: global___JobDefinitionLogConfiguration | None = ...,
        mount_points: collections.abc.Iterable[global___JobDefinitionMountPoints] | None = ...,
        execution_role_arn: builtins.str = ...,
        volumes: collections.abc.Iterable[global___JobDefinitionVolumes] | None = ...,
        command: collections.abc.Iterable[builtins.str] | None = ...,
        environment: collections.abc.Iterable[global___JobDefinitionEnvironment] | None = ...,
        ulimits: collections.abc.Iterable[global___JobDefinitionUlimit] | None = ...,
        instance_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["linux_parameters", b"linux_parameters", "log_configuration", b"log_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "environment", b"environment", "execution_role_arn", b"execution_role_arn", "image", b"image", "instance_type", b"instance_type", "job_role_arn", b"job_role_arn", "linux_parameters", b"linux_parameters", "log_configuration", b"log_configuration", "memory", b"memory", "mount_points", b"mount_points", "privileged", b"privileged", "readonly_root_filesystem", b"readonly_root_filesystem", "resource_info", b"resource_info", "resource_requirements", b"resource_requirements", "secrets", b"secrets", "ulimits", b"ulimits", "user", b"user", "vcpus", b"vcpus", "volumes", b"volumes"]) -> None: ...

global___JobDefinitionContainerProperties = JobDefinitionContainerProperties

@typing_extensions.final
class JobDefinitionNodeRangeProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTAINER_FIELD_NUMBER: builtins.int
    TARGET_NODES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def container(self) -> global___JobDefinitionContainerProperties: ...
    target_nodes: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        container: global___JobDefinitionContainerProperties | None = ...,
        target_nodes: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container", b"container", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container", b"container", "resource_info", b"resource_info", "target_nodes", b"target_nodes"]) -> None: ...

global___JobDefinitionNodeRangeProperty = JobDefinitionNodeRangeProperty

@typing_extensions.final
class JobDefinitionNodeProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAIN_NODE_FIELD_NUMBER: builtins.int
    NODE_RANGE_PROPERTIES_FIELD_NUMBER: builtins.int
    NUM_NODES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    main_node: builtins.int
    @property
    def node_range_properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobDefinitionNodeRangeProperty]: ...
    num_nodes: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        main_node: builtins.int = ...,
        node_range_properties: collections.abc.Iterable[global___JobDefinitionNodeRangeProperty] | None = ...,
        num_nodes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["main_node", b"main_node", "node_range_properties", b"node_range_properties", "num_nodes", b"num_nodes", "resource_info", b"resource_info"]) -> None: ...

global___JobDefinitionNodeProperties = JobDefinitionNodeProperties

@typing_extensions.final
class JobDefinitionTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTEMPT_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    attempt_duration_seconds: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attempt_duration_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attempt_duration_seconds", b"attempt_duration_seconds", "resource_info", b"resource_info"]) -> None: ...

global___JobDefinitionTimeout = JobDefinitionTimeout

@typing_extensions.final
class JobDefinitionRetryStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTEMPTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    attempts: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attempts: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attempts", b"attempts", "resource_info", b"resource_info"]) -> None: ...

global___JobDefinitionRetryStrategy = JobDefinitionRetryStrategy

@typing_extensions.final
class JobDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    NODE_PROPERTIES_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    CONTAINER_PROPERTIES_FIELD_NUMBER: builtins.int
    JOB_DEFINITION_NAME_FIELD_NUMBER: builtins.int
    RETRY_STRATEGY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    type: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def node_properties(self) -> global___JobDefinitionNodeProperties: ...
    @property
    def timeout(self) -> global___JobDefinitionTimeout: ...
    @property
    def container_properties(self) -> global___JobDefinitionContainerProperties: ...
    job_definition_name: builtins.str
    @property
    def retry_strategy(self) -> global___JobDefinitionRetryStrategy: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        type: builtins.str = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        node_properties: global___JobDefinitionNodeProperties | None = ...,
        timeout: global___JobDefinitionTimeout | None = ...,
        container_properties: global___JobDefinitionContainerProperties | None = ...,
        job_definition_name: builtins.str = ...,
        retry_strategy: global___JobDefinitionRetryStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_properties", b"container_properties", "node_properties", b"node_properties", "resource_info", b"resource_info", "retry_strategy", b"retry_strategy", "timeout", b"timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_properties", b"container_properties", "job_definition_name", b"job_definition_name", "node_properties", b"node_properties", "parameters", b"parameters", "resource_info", b"resource_info", "retry_strategy", b"retry_strategy", "timeout", b"timeout", "type", b"type"]) -> None: ...

global___JobDefinition = JobDefinition

@typing_extensions.final
class JobQueueComputeEnvironmentOrder(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPUTE_ENVIRONMENT_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    compute_environment: builtins.str
    order: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        compute_environment: builtins.str = ...,
        order: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_environment", b"compute_environment", "order", b"order", "resource_info", b"resource_info"]) -> None: ...

global___JobQueueComputeEnvironmentOrder = JobQueueComputeEnvironmentOrder

@typing_extensions.final
class JobQueue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPUTE_ENVIRONMENT_ORDER_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    JOB_QUEUE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def compute_environment_order(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobQueueComputeEnvironmentOrder]: ...
    priority: builtins.int
    state: builtins.str
    job_queue_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        compute_environment_order: collections.abc.Iterable[global___JobQueueComputeEnvironmentOrder] | None = ...,
        priority: builtins.int = ...,
        state: builtins.str = ...,
        job_queue_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_environment_order", b"compute_environment_order", "job_queue_name", b"job_queue_name", "priority", b"priority", "resource_info", b"resource_info", "state", b"state"]) -> None: ...

global___JobQueue = JobQueue



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class VirtualMachinesExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "properties", b"properties", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___VirtualMachinesExtensions = VirtualMachinesExtensions

@typing_extensions.final
class AvailabilitySet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___AvailabilitySet = AvailabilitySet

@typing_extensions.final
class Microsoft_Compute_VirtualMachines(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIRTUAL_MACHINES_FIELD_NUMBER: builtins.int
    @property
    def virtual_machines(self) -> global___VirtualMachines: ...
    def __init__(
        self,
        *,
        virtual_machines: global___VirtualMachines | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["virtual_machines", b"virtual_machines"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["virtual_machines", b"virtual_machines"]) -> None: ...

global___Microsoft_Compute_VirtualMachines = Microsoft_Compute_VirtualMachines

@typing_extensions.final
class VirtualMachinesRunCommands(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ASYNC_EXECUTION_FIELD_NUMBER: builtins.int
    ERROR_BLOB_URI_FIELD_NUMBER: builtins.int
    OUTPUT_BLOB_URI_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    PROTECTED_PARAMETERS_FIELD_NUMBER: builtins.int
    RUN_AS_PASSWORD_FIELD_NUMBER: builtins.int
    RUN_AS_USER_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TIMEOUT_IN_SECONDS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    async_execution: builtins.bool
    error_blob_uri: builtins.str
    output_blob_uri: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RunCommandInputParameter]: ...
    @property
    def protected_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RunCommandInputParameter]: ...
    run_as_password: builtins.str
    run_as_user: builtins.str
    @property
    def source(self) -> global___VirtualMachineRunCommandScriptSource: ...
    timeout_in_seconds: builtins.int
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        async_execution: builtins.bool = ...,
        error_blob_uri: builtins.str = ...,
        output_blob_uri: builtins.str = ...,
        parameters: collections.abc.Iterable[global___RunCommandInputParameter] | None = ...,
        protected_parameters: collections.abc.Iterable[global___RunCommandInputParameter] | None = ...,
        run_as_password: builtins.str = ...,
        run_as_user: builtins.str = ...,
        source: global___VirtualMachineRunCommandScriptSource | None = ...,
        timeout_in_seconds: builtins.int = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["async_execution", b"async_execution", "error_blob_uri", b"error_blob_uri", "location", b"location", "name", b"name", "output_blob_uri", b"output_blob_uri", "parameters", b"parameters", "protected_parameters", b"protected_parameters", "resource_info", b"resource_info", "run_as_password", b"run_as_password", "run_as_user", b"run_as_user", "source", b"source", "tags", b"tags", "timeout_in_seconds", b"timeout_in_seconds"]) -> None: ...

global___VirtualMachinesRunCommands = VirtualMachinesRunCommands

@typing_extensions.final
class VirtualMachineRunCommandScriptSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_ID_FIELD_NUMBER: builtins.int
    SCRIPT_FIELD_NUMBER: builtins.int
    SCRIPT_URI_FIELD_NUMBER: builtins.int
    command_id: builtins.str
    script: builtins.str
    script_uri: builtins.str
    def __init__(
        self,
        *,
        command_id: builtins.str = ...,
        script: builtins.str = ...,
        script_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command_id", b"command_id", "script", b"script", "script_uri", b"script_uri"]) -> None: ...

global___VirtualMachineRunCommandScriptSource = VirtualMachineRunCommandScriptSource

@typing_extensions.final
class RunCommandInputParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___RunCommandInputParameter = RunCommandInputParameter

@typing_extensions.final
class VirtualMachines(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXTENDED_LOCATION_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PLAN_FIELD_NUMBER: builtins.int
    ADDITIONAL_CAPABILITIES_FIELD_NUMBER: builtins.int
    APPLICATION_PROFILE_FIELD_NUMBER: builtins.int
    BILLING_PROFILE_FIELD_NUMBER: builtins.int
    CAPACITY_RESERVATION_FIELD_NUMBER: builtins.int
    DIAGNOSTICS_PROFILE_FIELD_NUMBER: builtins.int
    EVICTION_POLICY_FIELD_NUMBER: builtins.int
    EXTENSIONS_TIME_BUDGET_FIELD_NUMBER: builtins.int
    HARDWARE_PROFILE_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    HOST_GROUP_FIELD_NUMBER: builtins.int
    LICENSE_TYPE_FIELD_NUMBER: builtins.int
    NETWORK_PROFILE_FIELD_NUMBER: builtins.int
    OS_PROFILE_FIELD_NUMBER: builtins.int
    PLATFORM_FAULT_DOMAIN_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    PROXIMITY_PLACEMENT_GROUP_FIELD_NUMBER: builtins.int
    SCHEDULED_EVENTS_PROFILE_FIELD_NUMBER: builtins.int
    SECURITY_PROFILE_FIELD_NUMBER: builtins.int
    STORAGE_PROFILE_FIELD_NUMBER: builtins.int
    USER_DATA_FIELD_NUMBER: builtins.int
    VIRTUAL_MACHINE_SCALE_SET_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ZONES_FIELD_NUMBER: builtins.int
    VIRTUAL_MACHINES_EXTENSIONS_FIELD_NUMBER: builtins.int
    VIRTUAL_MACHINES_RUN_COMMANDS_FIELD_NUMBER: builtins.int
    AVAILABILITY_SET_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def extended_location(self) -> global___ExtendedLocation: ...
    @property
    def identity(self) -> global___VirtualMachineIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def plan(self) -> global___Plan: ...
    @property
    def additional_capabilities(self) -> global___AdditionalCapabilities: ...
    @property
    def application_profile(self) -> global___ApplicationProfile: ...
    @property
    def billing_profile(self) -> global___BillingProfile: ...
    @property
    def capacity_reservation(self) -> global___CapacityReservationProfile: ...
    @property
    def diagnostics_profile(self) -> global___DiagnosticsProfile: ...
    eviction_policy: builtins.str
    extensions_time_budget: builtins.str
    @property
    def hardware_profile(self) -> global___HardwareProfile: ...
    host: builtins.str
    host_group: builtins.str
    license_type: builtins.str
    @property
    def network_profile(self) -> global___NetworkProfile: ...
    @property
    def os_profile(self) -> global___OSProfile: ...
    platform_fault_domain: builtins.int
    priority: builtins.str
    proximity_placement_group: builtins.str
    @property
    def scheduled_events_profile(self) -> global___ScheduledEventsProfile: ...
    @property
    def security_profile(self) -> global___SecurityProfile: ...
    @property
    def storage_profile(self) -> global___StorageProfile: ...
    user_data: builtins.str
    virtual_machine_scale_set: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def virtual_machines_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualMachinesExtensions]: ...
    @property
    def virtual_machines_run_commands(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualMachinesRunCommands]: ...
    @property
    def availability_set(self) -> global___AvailabilitySet: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        extended_location: global___ExtendedLocation | None = ...,
        identity: global___VirtualMachineIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        plan: global___Plan | None = ...,
        additional_capabilities: global___AdditionalCapabilities | None = ...,
        application_profile: global___ApplicationProfile | None = ...,
        billing_profile: global___BillingProfile | None = ...,
        capacity_reservation: global___CapacityReservationProfile | None = ...,
        diagnostics_profile: global___DiagnosticsProfile | None = ...,
        eviction_policy: builtins.str = ...,
        extensions_time_budget: builtins.str = ...,
        hardware_profile: global___HardwareProfile | None = ...,
        host: builtins.str = ...,
        host_group: builtins.str = ...,
        license_type: builtins.str = ...,
        network_profile: global___NetworkProfile | None = ...,
        os_profile: global___OSProfile | None = ...,
        platform_fault_domain: builtins.int = ...,
        priority: builtins.str = ...,
        proximity_placement_group: builtins.str = ...,
        scheduled_events_profile: global___ScheduledEventsProfile | None = ...,
        security_profile: global___SecurityProfile | None = ...,
        storage_profile: global___StorageProfile | None = ...,
        user_data: builtins.str = ...,
        virtual_machine_scale_set: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zones: collections.abc.Iterable[builtins.str] | None = ...,
        virtual_machines_extensions: collections.abc.Iterable[global___VirtualMachinesExtensions] | None = ...,
        virtual_machines_run_commands: collections.abc.Iterable[global___VirtualMachinesRunCommands] | None = ...,
        availability_set: global___AvailabilitySet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["additional_capabilities", b"additional_capabilities", "application_profile", b"application_profile", "availability_set", b"availability_set", "billing_profile", b"billing_profile", "capacity_reservation", b"capacity_reservation", "diagnostics_profile", b"diagnostics_profile", "extended_location", b"extended_location", "hardware_profile", b"hardware_profile", "identity", b"identity", "network_profile", b"network_profile", "os_profile", b"os_profile", "plan", b"plan", "resource_info", b"resource_info", "scheduled_events_profile", b"scheduled_events_profile", "security_profile", b"security_profile", "storage_profile", b"storage_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_capabilities", b"additional_capabilities", "application_profile", b"application_profile", "availability_set", b"availability_set", "billing_profile", b"billing_profile", "capacity_reservation", b"capacity_reservation", "diagnostics_profile", b"diagnostics_profile", "eviction_policy", b"eviction_policy", "extended_location", b"extended_location", "extensions_time_budget", b"extensions_time_budget", "hardware_profile", b"hardware_profile", "host", b"host", "host_group", b"host_group", "identity", b"identity", "license_type", b"license_type", "location", b"location", "name", b"name", "network_profile", b"network_profile", "os_profile", b"os_profile", "plan", b"plan", "platform_fault_domain", b"platform_fault_domain", "priority", b"priority", "proximity_placement_group", b"proximity_placement_group", "resource_info", b"resource_info", "scheduled_events_profile", b"scheduled_events_profile", "security_profile", b"security_profile", "storage_profile", b"storage_profile", "tags", b"tags", "user_data", b"user_data", "virtual_machine_scale_set", b"virtual_machine_scale_set", "virtual_machines_extensions", b"virtual_machines_extensions", "virtual_machines_run_commands", b"virtual_machines_run_commands", "zones", b"zones"]) -> None: ...

global___VirtualMachines = VirtualMachines

@typing_extensions.final
class StorageProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_DISKS_FIELD_NUMBER: builtins.int
    IMAGE_REFERENCE_FIELD_NUMBER: builtins.int
    OS_DISK_FIELD_NUMBER: builtins.int
    @property
    def data_disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataDisk]: ...
    @property
    def image_reference(self) -> global___ImageReference: ...
    @property
    def os_disk(self) -> global___OSDisk: ...
    def __init__(
        self,
        *,
        data_disks: collections.abc.Iterable[global___DataDisk] | None = ...,
        image_reference: global___ImageReference | None = ...,
        os_disk: global___OSDisk | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["image_reference", b"image_reference", "os_disk", b"os_disk"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_disks", b"data_disks", "image_reference", b"image_reference", "os_disk", b"os_disk"]) -> None: ...

global___StorageProfile = StorageProfile

@typing_extensions.final
class OSDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CACHING_FIELD_NUMBER: builtins.int
    CREATE_OPTION_FIELD_NUMBER: builtins.int
    DELETE_OPTION_FIELD_NUMBER: builtins.int
    DIFF_DISK_SETTINGS_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    ENCRYPTION_SETTINGS_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    MANAGED_DISK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OS_TYPE_FIELD_NUMBER: builtins.int
    VHD_FIELD_NUMBER: builtins.int
    WRITE_ACCELERATOR_ENABLED_FIELD_NUMBER: builtins.int
    caching: builtins.str
    create_option: builtins.str
    delete_option: builtins.str
    @property
    def diff_disk_settings(self) -> global___DiffDiskSettings: ...
    disk_size_gb: builtins.int
    @property
    def encryption_settings(self) -> global___DiskEncryptionSettings: ...
    @property
    def image(self) -> global___VirtualHardDisk: ...
    @property
    def managed_disk(self) -> global___ManagedDiskParameters: ...
    name: builtins.str
    os_type: builtins.str
    @property
    def vhd(self) -> global___VirtualHardDisk: ...
    write_accelerator_enabled: builtins.bool
    def __init__(
        self,
        *,
        caching: builtins.str = ...,
        create_option: builtins.str = ...,
        delete_option: builtins.str = ...,
        diff_disk_settings: global___DiffDiskSettings | None = ...,
        disk_size_gb: builtins.int = ...,
        encryption_settings: global___DiskEncryptionSettings | None = ...,
        image: global___VirtualHardDisk | None = ...,
        managed_disk: global___ManagedDiskParameters | None = ...,
        name: builtins.str = ...,
        os_type: builtins.str = ...,
        vhd: global___VirtualHardDisk | None = ...,
        write_accelerator_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["diff_disk_settings", b"diff_disk_settings", "encryption_settings", b"encryption_settings", "image", b"image", "managed_disk", b"managed_disk", "vhd", b"vhd"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["caching", b"caching", "create_option", b"create_option", "delete_option", b"delete_option", "diff_disk_settings", b"diff_disk_settings", "disk_size_gb", b"disk_size_gb", "encryption_settings", b"encryption_settings", "image", b"image", "managed_disk", b"managed_disk", "name", b"name", "os_type", b"os_type", "vhd", b"vhd", "write_accelerator_enabled", b"write_accelerator_enabled"]) -> None: ...

global___OSDisk = OSDisk

@typing_extensions.final
class DiskEncryptionSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    KEY_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    @property
    def disk_encryption_key(self) -> global___KeyVaultSecretReference: ...
    enabled: builtins.bool
    @property
    def key_encryption_key(self) -> global___KeyVaultKeyReference: ...
    def __init__(
        self,
        *,
        disk_encryption_key: global___KeyVaultSecretReference | None = ...,
        enabled: builtins.bool = ...,
        key_encryption_key: global___KeyVaultKeyReference | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_encryption_key", b"disk_encryption_key", "key_encryption_key", b"key_encryption_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk_encryption_key", b"disk_encryption_key", "enabled", b"enabled", "key_encryption_key", b"key_encryption_key"]) -> None: ...

global___DiskEncryptionSettings = DiskEncryptionSettings

@typing_extensions.final
class KeyVaultKeyReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_URL_FIELD_NUMBER: builtins.int
    SOURCE_VAULT_FIELD_NUMBER: builtins.int
    key_url: builtins.str
    source_vault: builtins.str
    def __init__(
        self,
        *,
        key_url: builtins.str = ...,
        source_vault: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_url", b"key_url", "source_vault", b"source_vault"]) -> None: ...

global___KeyVaultKeyReference = KeyVaultKeyReference

@typing_extensions.final
class KeyVaultSecretReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_URL_FIELD_NUMBER: builtins.int
    SOURCE_VAULT_FIELD_NUMBER: builtins.int
    secret_url: builtins.str
    source_vault: builtins.str
    def __init__(
        self,
        *,
        secret_url: builtins.str = ...,
        source_vault: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret_url", b"secret_url", "source_vault", b"source_vault"]) -> None: ...

global___KeyVaultSecretReference = KeyVaultSecretReference

@typing_extensions.final
class DiffDiskSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTION_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    option: builtins.str
    placement: builtins.str
    def __init__(
        self,
        *,
        option: builtins.str = ...,
        placement: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["option", b"option", "placement", b"placement"]) -> None: ...

global___DiffDiskSettings = DiffDiskSettings

@typing_extensions.final
class ImageReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_GALLERY_IMAGE_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    OFFER_FIELD_NUMBER: builtins.int
    PUBLISHER_FIELD_NUMBER: builtins.int
    SHARED_GALLERY_IMAGE_ID_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    community_gallery_image_id: builtins.str
    id: builtins.str
    offer: builtins.str
    publisher: builtins.str
    shared_gallery_image_id: builtins.str
    sku: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        community_gallery_image_id: builtins.str = ...,
        id: builtins.str = ...,
        offer: builtins.str = ...,
        publisher: builtins.str = ...,
        shared_gallery_image_id: builtins.str = ...,
        sku: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["community_gallery_image_id", b"community_gallery_image_id", "id", b"id", "offer", b"offer", "publisher", b"publisher", "shared_gallery_image_id", b"shared_gallery_image_id", "sku", b"sku", "version", b"version"]) -> None: ...

global___ImageReference = ImageReference

@typing_extensions.final
class DataDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CACHING_FIELD_NUMBER: builtins.int
    CREATE_OPTION_FIELD_NUMBER: builtins.int
    DELETE_OPTION_FIELD_NUMBER: builtins.int
    DETACH_OPTION_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    LUN_FIELD_NUMBER: builtins.int
    MANAGED_DISK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TO_BE_DETACHED_FIELD_NUMBER: builtins.int
    VHD_FIELD_NUMBER: builtins.int
    WRITE_ACCELERATOR_ENABLED_FIELD_NUMBER: builtins.int
    caching: builtins.str
    create_option: builtins.str
    delete_option: builtins.str
    detach_option: builtins.str
    disk_size_gb: builtins.int
    @property
    def image(self) -> global___VirtualHardDisk: ...
    lun: builtins.int
    @property
    def managed_disk(self) -> global___ManagedDiskParameters: ...
    name: builtins.str
    to_be_detached: builtins.bool
    @property
    def vhd(self) -> global___VirtualHardDisk: ...
    write_accelerator_enabled: builtins.bool
    def __init__(
        self,
        *,
        caching: builtins.str = ...,
        create_option: builtins.str = ...,
        delete_option: builtins.str = ...,
        detach_option: builtins.str = ...,
        disk_size_gb: builtins.int = ...,
        image: global___VirtualHardDisk | None = ...,
        lun: builtins.int = ...,
        managed_disk: global___ManagedDiskParameters | None = ...,
        name: builtins.str = ...,
        to_be_detached: builtins.bool = ...,
        vhd: global___VirtualHardDisk | None = ...,
        write_accelerator_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["image", b"image", "managed_disk", b"managed_disk", "vhd", b"vhd"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["caching", b"caching", "create_option", b"create_option", "delete_option", b"delete_option", "detach_option", b"detach_option", "disk_size_gb", b"disk_size_gb", "image", b"image", "lun", b"lun", "managed_disk", b"managed_disk", "name", b"name", "to_be_detached", b"to_be_detached", "vhd", b"vhd", "write_accelerator_enabled", b"write_accelerator_enabled"]) -> None: ...

global___DataDisk = DataDisk

@typing_extensions.final
class ManagedDiskParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ENCRYPTION_SET_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    SECURITY_PROFILE_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_TYPE_FIELD_NUMBER: builtins.int
    @property
    def disk_encryption_set(self) -> global___DiskEncryptionSetParameters: ...
    id: builtins.str
    @property
    def security_profile(self) -> global___VMDiskSecurityProfile: ...
    storage_account_type: builtins.str
    def __init__(
        self,
        *,
        disk_encryption_set: global___DiskEncryptionSetParameters | None = ...,
        id: builtins.str = ...,
        security_profile: global___VMDiskSecurityProfile | None = ...,
        storage_account_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_encryption_set", b"disk_encryption_set", "security_profile", b"security_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk_encryption_set", b"disk_encryption_set", "id", b"id", "security_profile", b"security_profile", "storage_account_type", b"storage_account_type"]) -> None: ...

global___ManagedDiskParameters = ManagedDiskParameters

@typing_extensions.final
class VMDiskSecurityProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ENCRYPTION_SET_FIELD_NUMBER: builtins.int
    SECURITY_ENCRYPTION_TYPE_FIELD_NUMBER: builtins.int
    @property
    def disk_encryption_set(self) -> global___DiskEncryptionSetParameters: ...
    security_encryption_type: builtins.str
    def __init__(
        self,
        *,
        disk_encryption_set: global___DiskEncryptionSetParameters | None = ...,
        security_encryption_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_encryption_set", b"disk_encryption_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk_encryption_set", b"disk_encryption_set", "security_encryption_type", b"security_encryption_type"]) -> None: ...

global___VMDiskSecurityProfile = VMDiskSecurityProfile

@typing_extensions.final
class DiskEncryptionSetParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___DiskEncryptionSetParameters = DiskEncryptionSetParameters

@typing_extensions.final
class VirtualHardDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URI_FIELD_NUMBER: builtins.int
    uri: builtins.str
    def __init__(
        self,
        *,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["uri", b"uri"]) -> None: ...

global___VirtualHardDisk = VirtualHardDisk

@typing_extensions.final
class SecurityProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCRYPTION_AT_HOST_FIELD_NUMBER: builtins.int
    SECURITY_TYPE_FIELD_NUMBER: builtins.int
    UEFI_SETTINGS_FIELD_NUMBER: builtins.int
    encryption_at_host: builtins.bool
    security_type: builtins.str
    @property
    def uefi_settings(self) -> global___UefiSettings: ...
    def __init__(
        self,
        *,
        encryption_at_host: builtins.bool = ...,
        security_type: builtins.str = ...,
        uefi_settings: global___UefiSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["uefi_settings", b"uefi_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryption_at_host", b"encryption_at_host", "security_type", b"security_type", "uefi_settings", b"uefi_settings"]) -> None: ...

global___SecurityProfile = SecurityProfile

@typing_extensions.final
class UefiSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURE_BOOT_ENABLED_FIELD_NUMBER: builtins.int
    V_TPM_ENABLED_FIELD_NUMBER: builtins.int
    secure_boot_enabled: builtins.bool
    v_tpm_enabled: builtins.bool
    def __init__(
        self,
        *,
        secure_boot_enabled: builtins.bool = ...,
        v_tpm_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secure_boot_enabled", b"secure_boot_enabled", "v_tpm_enabled", b"v_tpm_enabled"]) -> None: ...

global___UefiSettings = UefiSettings

@typing_extensions.final
class ScheduledEventsProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TERMINATE_NOTIFICATION_PROFILE_FIELD_NUMBER: builtins.int
    @property
    def terminate_notification_profile(self) -> global___TerminateNotificationProfile: ...
    def __init__(
        self,
        *,
        terminate_notification_profile: global___TerminateNotificationProfile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["terminate_notification_profile", b"terminate_notification_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["terminate_notification_profile", b"terminate_notification_profile"]) -> None: ...

global___ScheduledEventsProfile = ScheduledEventsProfile

@typing_extensions.final
class TerminateNotificationProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    NOT_BEFORE_TIMEOUT_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    not_before_timeout: builtins.str
    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
        not_before_timeout: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable", b"enable", "not_before_timeout", b"not_before_timeout"]) -> None: ...

global___TerminateNotificationProfile = TerminateNotificationProfile

@typing_extensions.final
class OSProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMIN_PASSWORD_FIELD_NUMBER: builtins.int
    ADMIN_USERNAME_FIELD_NUMBER: builtins.int
    ALLOW_EXTENSION_OPERATIONS_FIELD_NUMBER: builtins.int
    COMPUTER_NAME_FIELD_NUMBER: builtins.int
    CUSTOM_DATA_FIELD_NUMBER: builtins.int
    LINUX_CONFIGURATION_FIELD_NUMBER: builtins.int
    REQUIRE_GUEST_PROVISION_SIGNAL_FIELD_NUMBER: builtins.int
    SECRETS_FIELD_NUMBER: builtins.int
    WINDOWS_CONFIGURATION_FIELD_NUMBER: builtins.int
    admin_password: builtins.str
    admin_username: builtins.str
    allow_extension_operations: builtins.bool
    computer_name: builtins.str
    custom_data: builtins.str
    @property
    def linux_configuration(self) -> global___LinuxConfiguration: ...
    require_guest_provision_signal: builtins.bool
    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultSecretGroup]: ...
    @property
    def windows_configuration(self) -> global___WindowsConfiguration: ...
    def __init__(
        self,
        *,
        admin_password: builtins.str = ...,
        admin_username: builtins.str = ...,
        allow_extension_operations: builtins.bool = ...,
        computer_name: builtins.str = ...,
        custom_data: builtins.str = ...,
        linux_configuration: global___LinuxConfiguration | None = ...,
        require_guest_provision_signal: builtins.bool = ...,
        secrets: collections.abc.Iterable[global___VaultSecretGroup] | None = ...,
        windows_configuration: global___WindowsConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["linux_configuration", b"linux_configuration", "windows_configuration", b"windows_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_password", b"admin_password", "admin_username", b"admin_username", "allow_extension_operations", b"allow_extension_operations", "computer_name", b"computer_name", "custom_data", b"custom_data", "linux_configuration", b"linux_configuration", "require_guest_provision_signal", b"require_guest_provision_signal", "secrets", b"secrets", "windows_configuration", b"windows_configuration"]) -> None: ...

global___OSProfile = OSProfile

@typing_extensions.final
class WindowsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITIONAL_UNATTEND_CONTENT_FIELD_NUMBER: builtins.int
    ENABLE_AUTOMATIC_UPDATES_FIELD_NUMBER: builtins.int
    PATCH_SETTINGS_FIELD_NUMBER: builtins.int
    PROVISION_V_M_AGENT_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    WIN_R_M_FIELD_NUMBER: builtins.int
    @property
    def additional_unattend_content(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdditionalUnattendContent]: ...
    enable_automatic_updates: builtins.bool
    @property
    def patch_settings(self) -> global___PatchSettings: ...
    provision_v_m_agent: builtins.bool
    time_zone: builtins.str
    @property
    def win_r_m(self) -> global___WinRMConfiguration: ...
    def __init__(
        self,
        *,
        additional_unattend_content: collections.abc.Iterable[global___AdditionalUnattendContent] | None = ...,
        enable_automatic_updates: builtins.bool = ...,
        patch_settings: global___PatchSettings | None = ...,
        provision_v_m_agent: builtins.bool = ...,
        time_zone: builtins.str = ...,
        win_r_m: global___WinRMConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["patch_settings", b"patch_settings", "win_r_m", b"win_r_m"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_unattend_content", b"additional_unattend_content", "enable_automatic_updates", b"enable_automatic_updates", "patch_settings", b"patch_settings", "provision_v_m_agent", b"provision_v_m_agent", "time_zone", b"time_zone", "win_r_m", b"win_r_m"]) -> None: ...

global___WindowsConfiguration = WindowsConfiguration

@typing_extensions.final
class WinRMConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LISTENERS_FIELD_NUMBER: builtins.int
    @property
    def listeners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WinRMListener]: ...
    def __init__(
        self,
        *,
        listeners: collections.abc.Iterable[global___WinRMListener] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["listeners", b"listeners"]) -> None: ...

global___WinRMConfiguration = WinRMConfiguration

@typing_extensions.final
class WinRMListener(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_URL_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    certificate_url: builtins.str
    protocol: builtins.str
    def __init__(
        self,
        *,
        certificate_url: builtins.str = ...,
        protocol: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_url", b"certificate_url", "protocol", b"protocol"]) -> None: ...

global___WinRMListener = WinRMListener

@typing_extensions.final
class PatchSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSESSMENT_MODE_FIELD_NUMBER: builtins.int
    ENABLE_HOTPATCHING_FIELD_NUMBER: builtins.int
    PATCH_MODE_FIELD_NUMBER: builtins.int
    assessment_mode: builtins.str
    enable_hotpatching: builtins.bool
    patch_mode: builtins.str
    def __init__(
        self,
        *,
        assessment_mode: builtins.str = ...,
        enable_hotpatching: builtins.bool = ...,
        patch_mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["assessment_mode", b"assessment_mode", "enable_hotpatching", b"enable_hotpatching", "patch_mode", b"patch_mode"]) -> None: ...

global___PatchSettings = PatchSettings

@typing_extensions.final
class AdditionalUnattendContent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_NAME_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PASS_NAME_FIELD_NUMBER: builtins.int
    SETTING_NAME_FIELD_NUMBER: builtins.int
    component_name: builtins.str
    content: builtins.str
    pass_name: builtins.str
    setting_name: builtins.str
    def __init__(
        self,
        *,
        component_name: builtins.str = ...,
        content: builtins.str = ...,
        pass_name: builtins.str = ...,
        setting_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_name", b"component_name", "content", b"content", "pass_name", b"pass_name", "setting_name", b"setting_name"]) -> None: ...

global___AdditionalUnattendContent = AdditionalUnattendContent

@typing_extensions.final
class VaultSecretGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_VAULT_FIELD_NUMBER: builtins.int
    VAULT_CERTIFICATES_FIELD_NUMBER: builtins.int
    source_vault: builtins.str
    @property
    def vault_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultCertificate]: ...
    def __init__(
        self,
        *,
        source_vault: builtins.str = ...,
        vault_certificates: collections.abc.Iterable[global___VaultCertificate] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_vault", b"source_vault", "vault_certificates", b"vault_certificates"]) -> None: ...

global___VaultSecretGroup = VaultSecretGroup

@typing_extensions.final
class VaultCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_STORE_FIELD_NUMBER: builtins.int
    CERTIFICATE_URL_FIELD_NUMBER: builtins.int
    certificate_store: builtins.str
    certificate_url: builtins.str
    def __init__(
        self,
        *,
        certificate_store: builtins.str = ...,
        certificate_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_store", b"certificate_store", "certificate_url", b"certificate_url"]) -> None: ...

global___VaultCertificate = VaultCertificate

@typing_extensions.final
class LinuxConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLE_PASSWORD_AUTHENTICATION_FIELD_NUMBER: builtins.int
    PATCH_SETTINGS_FIELD_NUMBER: builtins.int
    PROVISION_V_M_AGENT_FIELD_NUMBER: builtins.int
    SSH_FIELD_NUMBER: builtins.int
    disable_password_authentication: builtins.bool
    @property
    def patch_settings(self) -> global___LinuxPatchSettings: ...
    provision_v_m_agent: builtins.bool
    @property
    def ssh(self) -> global___SshConfiguration: ...
    def __init__(
        self,
        *,
        disable_password_authentication: builtins.bool = ...,
        patch_settings: global___LinuxPatchSettings | None = ...,
        provision_v_m_agent: builtins.bool = ...,
        ssh: global___SshConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["patch_settings", b"patch_settings", "ssh", b"ssh"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_password_authentication", b"disable_password_authentication", "patch_settings", b"patch_settings", "provision_v_m_agent", b"provision_v_m_agent", "ssh", b"ssh"]) -> None: ...

global___LinuxConfiguration = LinuxConfiguration

@typing_extensions.final
class SshConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLIC_KEYS_FIELD_NUMBER: builtins.int
    @property
    def public_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SshPublicKey]: ...
    def __init__(
        self,
        *,
        public_keys: collections.abc.Iterable[global___SshPublicKey] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["public_keys", b"public_keys"]) -> None: ...

global___SshConfiguration = SshConfiguration

@typing_extensions.final
class SshPublicKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_DATA_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    key_data: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        key_data: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_data", b"key_data", "path", b"path"]) -> None: ...

global___SshPublicKey = SshPublicKey

@typing_extensions.final
class LinuxPatchSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSESSMENT_MODE_FIELD_NUMBER: builtins.int
    PATCH_MODE_FIELD_NUMBER: builtins.int
    assessment_mode: builtins.str
    patch_mode: builtins.str
    def __init__(
        self,
        *,
        assessment_mode: builtins.str = ...,
        patch_mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["assessment_mode", b"assessment_mode", "patch_mode", b"patch_mode"]) -> None: ...

global___LinuxPatchSettings = LinuxPatchSettings

@typing_extensions.final
class NetworkProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_API_VERSION_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACE_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACES_FIELD_NUMBER: builtins.int
    network_api_version: builtins.str
    @property
    def network_interface_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualMachineNetworkInterfaceConfiguration]: ...
    @property
    def network_interfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkInterfaceReference]: ...
    def __init__(
        self,
        *,
        network_api_version: builtins.str = ...,
        network_interface_configurations: collections.abc.Iterable[global___VirtualMachineNetworkInterfaceConfiguration] | None = ...,
        network_interfaces: collections.abc.Iterable[global___NetworkInterfaceReference] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_api_version", b"network_api_version", "network_interface_configurations", b"network_interface_configurations", "network_interfaces", b"network_interfaces"]) -> None: ...

global___NetworkProfile = NetworkProfile

@typing_extensions.final
class NetworkInterfaceReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DELETE_OPTION_FIELD_NUMBER: builtins.int
    PRIMARY_FIELD_NUMBER: builtins.int
    id: builtins.str
    delete_option: builtins.str
    primary: builtins.bool
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        delete_option: builtins.str = ...,
        primary: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_option", b"delete_option", "id", b"id", "primary", b"primary"]) -> None: ...

global___NetworkInterfaceReference = NetworkInterfaceReference

@typing_extensions.final
class VirtualMachineNetworkInterfaceConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DELETE_OPTION_FIELD_NUMBER: builtins.int
    DNS_SETTINGS_FIELD_NUMBER: builtins.int
    DSCP_CONFIGURATION_FIELD_NUMBER: builtins.int
    ENABLE_ACCELERATED_NETWORKING_FIELD_NUMBER: builtins.int
    ENABLE_FPGA_FIELD_NUMBER: builtins.int
    ENABLE_IP_FORWARDING_FIELD_NUMBER: builtins.int
    IP_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    NETWORK_SECURITY_GROUP_FIELD_NUMBER: builtins.int
    PRIMARY_FIELD_NUMBER: builtins.int
    name: builtins.str
    delete_option: builtins.str
    @property
    def dns_settings(self) -> global___VirtualMachineNetworkInterfaceDnsSettingsConfiguration: ...
    dscp_configuration: builtins.str
    enable_accelerated_networking: builtins.bool
    enable_fpga: builtins.bool
    enable_ip_forwarding: builtins.bool
    @property
    def ip_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualMachineNetworkInterfaceIPConfiguration]: ...
    network_security_group: builtins.str
    primary: builtins.bool
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        delete_option: builtins.str = ...,
        dns_settings: global___VirtualMachineNetworkInterfaceDnsSettingsConfiguration | None = ...,
        dscp_configuration: builtins.str = ...,
        enable_accelerated_networking: builtins.bool = ...,
        enable_fpga: builtins.bool = ...,
        enable_ip_forwarding: builtins.bool = ...,
        ip_configurations: collections.abc.Iterable[global___VirtualMachineNetworkInterfaceIPConfiguration] | None = ...,
        network_security_group: builtins.str = ...,
        primary: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dns_settings", b"dns_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_option", b"delete_option", "dns_settings", b"dns_settings", "dscp_configuration", b"dscp_configuration", "enable_accelerated_networking", b"enable_accelerated_networking", "enable_fpga", b"enable_fpga", "enable_ip_forwarding", b"enable_ip_forwarding", "ip_configurations", b"ip_configurations", "name", b"name", "network_security_group", b"network_security_group", "primary", b"primary"]) -> None: ...

global___VirtualMachineNetworkInterfaceConfiguration = VirtualMachineNetworkInterfaceConfiguration

@typing_extensions.final
class VirtualMachineNetworkInterfaceIPConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    APPLICATION_GATEWAY_BACKEND_ADDRESS_POOLS_FIELD_NUMBER: builtins.int
    APPLICATION_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_BACKEND_ADDRESS_POOLS_FIELD_NUMBER: builtins.int
    PRIMARY_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ADDRESS_VERSION_FIELD_NUMBER: builtins.int
    PUBLIC_IP_ADDRESS_CONFIGURATION_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def application_gateway_backend_address_pools(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def application_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def load_balancer_backend_address_pools(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    primary: builtins.bool
    private_ip_address_version: builtins.str
    @property
    def public_ip_address_configuration(self) -> global___VirtualMachinePublicIPAddressConfiguration: ...
    subnet: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        application_gateway_backend_address_pools: collections.abc.Iterable[builtins.str] | None = ...,
        application_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        load_balancer_backend_address_pools: collections.abc.Iterable[builtins.str] | None = ...,
        primary: builtins.bool = ...,
        private_ip_address_version: builtins.str = ...,
        public_ip_address_configuration: global___VirtualMachinePublicIPAddressConfiguration | None = ...,
        subnet: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["public_ip_address_configuration", b"public_ip_address_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_gateway_backend_address_pools", b"application_gateway_backend_address_pools", "application_security_groups", b"application_security_groups", "load_balancer_backend_address_pools", b"load_balancer_backend_address_pools", "name", b"name", "primary", b"primary", "private_ip_address_version", b"private_ip_address_version", "public_ip_address_configuration", b"public_ip_address_configuration", "subnet", b"subnet"]) -> None: ...

global___VirtualMachineNetworkInterfaceIPConfiguration = VirtualMachineNetworkInterfaceIPConfiguration

@typing_extensions.final
class VirtualMachinePublicIPAddressConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DELETE_OPTION_FIELD_NUMBER: builtins.int
    DNS_SETTINGS_FIELD_NUMBER: builtins.int
    IDLE_TIMEOUT_IN_MINUTES_FIELD_NUMBER: builtins.int
    IP_TAGS_FIELD_NUMBER: builtins.int
    PUBLIC_IP_ADDRESS_VERSION_FIELD_NUMBER: builtins.int
    PUBLIC_IP_ALLOCATION_METHOD_FIELD_NUMBER: builtins.int
    PUBLIC_IP_PREFIX_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    name: builtins.str
    delete_option: builtins.str
    @property
    def dns_settings(self) -> global___VirtualMachinePublicIPAddressDnsSettingsConfiguration: ...
    idle_timeout_in_minutes: builtins.int
    @property
    def ip_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualMachineIpTag]: ...
    public_ip_address_version: builtins.str
    public_ip_allocation_method: builtins.str
    public_ip_prefix: builtins.str
    @property
    def sku(self) -> global___PublicIPAddressSku: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        delete_option: builtins.str = ...,
        dns_settings: global___VirtualMachinePublicIPAddressDnsSettingsConfiguration | None = ...,
        idle_timeout_in_minutes: builtins.int = ...,
        ip_tags: collections.abc.Iterable[global___VirtualMachineIpTag] | None = ...,
        public_ip_address_version: builtins.str = ...,
        public_ip_allocation_method: builtins.str = ...,
        public_ip_prefix: builtins.str = ...,
        sku: global___PublicIPAddressSku | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dns_settings", b"dns_settings", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_option", b"delete_option", "dns_settings", b"dns_settings", "idle_timeout_in_minutes", b"idle_timeout_in_minutes", "ip_tags", b"ip_tags", "name", b"name", "public_ip_address_version", b"public_ip_address_version", "public_ip_allocation_method", b"public_ip_allocation_method", "public_ip_prefix", b"public_ip_prefix", "sku", b"sku"]) -> None: ...

global___VirtualMachinePublicIPAddressConfiguration = VirtualMachinePublicIPAddressConfiguration

@typing_extensions.final
class PublicIPAddressSku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    name: builtins.str
    tier: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "tier", b"tier"]) -> None: ...

global___PublicIPAddressSku = PublicIPAddressSku

@typing_extensions.final
class VirtualMachineIpTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_TAG_TYPE_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    ip_tag_type: builtins.str
    tag: builtins.str
    def __init__(
        self,
        *,
        ip_tag_type: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_tag_type", b"ip_tag_type", "tag", b"tag"]) -> None: ...

global___VirtualMachineIpTag = VirtualMachineIpTag

@typing_extensions.final
class VirtualMachinePublicIPAddressDnsSettingsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_NAME_LABEL_FIELD_NUMBER: builtins.int
    domain_name_label: builtins.str
    def __init__(
        self,
        *,
        domain_name_label: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain_name_label", b"domain_name_label"]) -> None: ...

global___VirtualMachinePublicIPAddressDnsSettingsConfiguration = VirtualMachinePublicIPAddressDnsSettingsConfiguration

@typing_extensions.final
class VirtualMachineNetworkInterfaceDnsSettingsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_SERVERS_FIELD_NUMBER: builtins.int
    @property
    def dns_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        dns_servers: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_servers", b"dns_servers"]) -> None: ...

global___VirtualMachineNetworkInterfaceDnsSettingsConfiguration = VirtualMachineNetworkInterfaceDnsSettingsConfiguration

@typing_extensions.final
class HardwareProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VM_SIZE_FIELD_NUMBER: builtins.int
    VM_SIZE_PROPERTIES_FIELD_NUMBER: builtins.int
    vm_size: builtins.str
    @property
    def vm_size_properties(self) -> global___VMSizeProperties: ...
    def __init__(
        self,
        *,
        vm_size: builtins.str = ...,
        vm_size_properties: global___VMSizeProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vm_size_properties", b"vm_size_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["vm_size", b"vm_size", "vm_size_properties", b"vm_size_properties"]) -> None: ...

global___HardwareProfile = HardwareProfile

@typing_extensions.final
class VMSizeProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    V_CPUS_AVAILABLE_FIELD_NUMBER: builtins.int
    V_CPUS_PER_CORE_FIELD_NUMBER: builtins.int
    v_cpus_available: builtins.int
    v_cpus_per_core: builtins.int
    def __init__(
        self,
        *,
        v_cpus_available: builtins.int = ...,
        v_cpus_per_core: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["v_cpus_available", b"v_cpus_available", "v_cpus_per_core", b"v_cpus_per_core"]) -> None: ...

global___VMSizeProperties = VMSizeProperties

@typing_extensions.final
class DiagnosticsProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOT_DIAGNOSTICS_FIELD_NUMBER: builtins.int
    @property
    def boot_diagnostics(self) -> global___BootDiagnostics: ...
    def __init__(
        self,
        *,
        boot_diagnostics: global___BootDiagnostics | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["boot_diagnostics", b"boot_diagnostics"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["boot_diagnostics", b"boot_diagnostics"]) -> None: ...

global___DiagnosticsProfile = DiagnosticsProfile

@typing_extensions.final
class BootDiagnostics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    STORAGE_URI_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    storage_uri: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        storage_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "storage_uri", b"storage_uri"]) -> None: ...

global___BootDiagnostics = BootDiagnostics

@typing_extensions.final
class CapacityReservationProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_RESERVATION_GROUP_FIELD_NUMBER: builtins.int
    capacity_reservation_group: builtins.str
    def __init__(
        self,
        *,
        capacity_reservation_group: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity_reservation_group", b"capacity_reservation_group"]) -> None: ...

global___CapacityReservationProfile = CapacityReservationProfile

@typing_extensions.final
class BillingProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_PRICE_FIELD_NUMBER: builtins.int
    max_price: builtins.float
    def __init__(
        self,
        *,
        max_price: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_price", b"max_price"]) -> None: ...

global___BillingProfile = BillingProfile

@typing_extensions.final
class ApplicationProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_APPLICATIONS_FIELD_NUMBER: builtins.int
    @property
    def gallery_applications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VMGalleryApplication]: ...
    def __init__(
        self,
        *,
        gallery_applications: collections.abc.Iterable[global___VMGalleryApplication] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gallery_applications", b"gallery_applications"]) -> None: ...

global___ApplicationProfile = ApplicationProfile

@typing_extensions.final
class VMGalleryApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIGURATION_REFERENCE_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    PACKAGE_REFERENCE_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    configuration_reference: builtins.str
    order: builtins.int
    package_reference_id: builtins.str
    tags: builtins.str
    def __init__(
        self,
        *,
        configuration_reference: builtins.str = ...,
        order: builtins.int = ...,
        package_reference_id: builtins.str = ...,
        tags: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration_reference", b"configuration_reference", "order", b"order", "package_reference_id", b"package_reference_id", "tags", b"tags"]) -> None: ...

global___VMGalleryApplication = VMGalleryApplication

@typing_extensions.final
class AdditionalCapabilities(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HIBERNATION_ENABLED_FIELD_NUMBER: builtins.int
    ULTRA_SSD_ENABLED_FIELD_NUMBER: builtins.int
    hibernation_enabled: builtins.bool
    ultra_ssd_enabled: builtins.bool
    def __init__(
        self,
        *,
        hibernation_enabled: builtins.bool = ...,
        ultra_ssd_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hibernation_enabled", b"hibernation_enabled", "ultra_ssd_enabled", b"ultra_ssd_enabled"]) -> None: ...

global___AdditionalCapabilities = AdditionalCapabilities

@typing_extensions.final
class Plan(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PRODUCT_FIELD_NUMBER: builtins.int
    PROMOTION_CODE_FIELD_NUMBER: builtins.int
    PUBLISHER_FIELD_NUMBER: builtins.int
    name: builtins.str
    product: builtins.str
    promotion_code: builtins.str
    publisher: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        product: builtins.str = ...,
        promotion_code: builtins.str = ...,
        publisher: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "product", b"product", "promotion_code", b"promotion_code", "publisher", b"publisher"]) -> None: ...

global___Plan = Plan

@typing_extensions.final
class VirtualMachineIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___VirtualMachineIdentity = VirtualMachineIdentity

@typing_extensions.final
class ExtendedLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___ExtendedLocation = ExtendedLocation
